<?php
/*
Plugin Name: Media-search-by-Mbsmgroup
Plugin URI: https://mbsm.tn
Description: An easy way to control and display media types in your WordPress site with pagination, with links to their original post and open in a new tab. Optimized for SEO and security.
Version: 1.0
Author: Mbsmgroup
Author URI: https://Mbsm.tn
License: GPL2
*/

// Create the settings page in the admin menu
function media_control_create_menu() {
    add_menu_page(
        'Media Control',            // Page title
        'Media Control',            // Menu title
        'manage_options',           // Required permissions
        'media-control',            // Page slug
        'media_control_settings_page',  // Callback function for the page content
        'dashicons-images-alt2',    // Icon for the menu
        6                           // Menu position
    );
    
    // Add Installation Instructions page under the plugin menu
    add_submenu_page(
        'media-control',            // Parent menu slug
        'Installation Instructions', // Page title
        'Installation',              // Menu title
        'manage_options',            // Required permissions
        'media-control-installation', // Slug for the new page
        'media_control_installation_page' // Callback function
    );
}
add_action('admin_menu', 'media_control_create_menu');

// Settings page content (Main plugin settings)
function media_control_settings_page() {
    ?>
    <div class="wrap">
        <h2>Media Control Settings</h2>
        <form method="post" action="options.php">
            <?php
            settings_fields('media_control_settings_group');
            do_settings_sections('media-control');
            ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Number of files to display</th>
                    <td>
                        <input type="number" name="media_count" value="<?php echo esc_attr(get_option('media_count', 5)); ?>" />
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Installation instructions page content
function media_control_installation_page() {
    ?>
    <div class="wrap">
        <h2>Installation Instructions for Media Control Plugin</h2>
        <p><strong>Welcome to the Media Control Plugin! Follow the steps below to easily set up and use the plugin:</strong></p>
        <h3>Installation Steps</h3>
        <ol>
            <li>Download the plugin ZIP file from the WordPress repository or directly from the developer's website.</li>
            <li>In your WordPress dashboard, navigate to <strong>Plugins > Add New</strong>.</li>
            <li>Click on <strong>Upload Plugin</strong> and select the downloaded ZIP file.</li>
            <li>Click on <strong>Install Now</strong> and then activate the plugin once installed.</li>
        </ol>
        <h3>Configuration</h3>
        <ul>
            <li>Once activated, go to the <strong>Media Control</strong> menu in your dashboard.</li>
            <li>In the settings page, you can define the number of files to display per page in the media gallery.</li>
            <li>You can also filter the types of media (e.g., PDF, ZIP, images) you want to display using the shortcode.</li>
        </ul>
        <h3>Features and Benefits</h3>
        <ul>
            <li><strong>Performance Optimized:</strong> Media is displayed with pagination, improving load times and making it easier for users to browse large galleries.</li>
            <li><strong>SEO-Friendly:</strong> The plugin uses clean, accessible HTML output that is optimized for search engines. File types and media information are easy to index.</li>
            <li><strong>Enhanced Security:</strong> The plugin automatically filters out file types that are not safe (e.g., PHP, CSS, JS) and ensures your media gallery is secure.</li>
            <li><strong>Customizable:</strong> You can easily filter media by file type, and display it in an attractive, user-friendly gallery.</li>
        </ul>
        <h3>Why Use This Plugin?</h3>
        <p>The <strong>Media Control</strong> plugin provides a powerful and flexible way to manage your WordPress media files. It enables you to easily control the types of media displayed on your site, ensuring better user experience, improved SEO, and faster load times.</p>
        <h3>Safety and Security</h3>
        <p>This plugin ensures that only safe and valid file types are shown on your site. It filters out potentially harmful files like <code>php</code>, <code>css</code>, <code>access</code>, and <code>js</code> to keep your WordPress site safe from vulnerabilities.</p>
        <h3>Need Help?</h3>
        <p>If you have any questions or need assistance, feel free to contact the plugin author or visit the plugin support page.</p>
    </div>
    <?php
}

// Register plugin settings
function media_control_register_settings() {
    register_setting('media_control_settings_group', 'media_count');
}
add_action('admin_init', 'media_control_register_settings');

// Function to display media with pagination and filtering
function media_control_display_media($media_type, $media_count, $paged = 1) {
    // List of excluded file types for security reasons
    $excluded_file_types = array('php', 'css', 'access', 'js');

    // Exploding the provided media types into an array (supports multiple types)
    $file_types = explode(',', $media_type); // Support multiple file types by comma

    // Build the query arguments for media with pagination
    $args = array(
        'post_type'      => 'attachment',
        'posts_per_page' => $media_count,
        'paged'          => $paged,  // Adding pagination support
        'post_status'    => 'inherit',
    );

    // Exclude the specified file types from the query
    $args['meta_query'] = array(
        array(
            'key'     => '_wp_attachment_metadata',
            'value'   => implode('|', $file_types),
            'compare' => 'REGEXP',
        ),
    );

    // Query to get the media
    $media_query = new WP_Query($args);

    // Check if there are media items to display
    if ($media_query->have_posts()) {
        echo '<div class="media-gallery">';
        while ($media_query->have_posts()) {
            $media_query->the_post();
            $media_url = wp_get_attachment_url(get_the_ID());

            // Extract the file extension
            $file_extension = pathinfo($media_url, PATHINFO_EXTENSION);

            // Skip the file if it is in the excluded list
            if (in_array($file_extension, $excluded_file_types)) {
                continue; // Skip this file
            }

            // Get the parent post title, excerpt, URL, and image (featured image)
            $post_id = get_post_field('post_parent', get_the_ID());
            $post_title = get_the_title($post_id);
            $post_url = get_permalink($post_id);
            $post_excerpt = get_the_excerpt($post_id); // Get the excerpt of the post
            $post_image = get_the_post_thumbnail_url($post_id, 'medium'); // Get the featured image URL

            // Display the media content based on its type
            echo '<div class="media-item">';
            
            // Display the post image if available (using WordPress default styles)
            if ($post_image) {
                echo '<div class="media-post-image">';
                echo '<a href="' . esc_url($post_url) . '" target="_blank">';
                echo '<img src="' . esc_url($post_image) . '" alt="' . esc_attr($post_title) . '" class="wp-post-image" />';
                echo '</a>';
                echo '</div>';
            }

            // Display media content based on its file type
            if (in_array($file_extension, array('jpg', 'jpeg', 'png', 'gif'))) {
                echo '<a href="' . esc_url($media_url) . '" target="_blank">';
                echo '<img src="' . esc_url($media_url) . '" alt="' . esc_attr($post_title) . '" class="attachment-post-thumbnail size-post-thumbnail" />';
                echo '</a>';
            } elseif (in_array($file_extension, array('mp4', 'mov', 'avi'))) {
                echo '<a href="' . esc_url($media_url) . '" target="_blank">';
                echo '<video controls><source src="' . esc_url($media_url) . '" type="video/mp4"></video>';
                echo '</a>';
            } elseif (in_array($file_extension, array('mp3', 'wav', 'ogg'))) {
                echo '<a href="' . esc_url($media_url) . '" target="_blank">';
                echo '<audio controls><source src="' . esc_url($media_url) . '" type="audio/mpeg"></audio>';
                echo '</a>';
            } elseif ($file_extension === 'pdf') {
                echo '<div class="media-icon">';
                echo '<a href="' . esc_url($media_url) . '" target="_blank">Download ' . basename($media_url) . ' (PDF)</a>';
                echo '</div>';
            } elseif ($file_extension === 'zip') {
                echo '<div class="media-icon">';
                echo '<img src="' . esc_url(plugin_dir_url(__FILE__) . 'assets/zip-icon.png') . '" alt="ZIP Icon" />';
                echo '<a href="' . esc_url($media_url) . '" target="_blank">Download ' . basename($media_url) . ' (ZIP)</a>';
                echo '</div>';
            }

            // Display post excerpt, link, and title
            echo '<div class="post-info">';
            echo '<p><strong>Excerpt:</strong> ' . esc_html($post_excerpt) . '</p>';
            echo '<p><a href="' . esc_url($post_url) . '" target="_blank">View in the post: ' . esc_html($post_title) . '</a></p>';
						
            echo '<img src="https://mbsm.pro/images/pdf-icon.png" alt="PDF Icon" />';
			echo '<p></p>';


            echo '</div>';
            echo '</div>';
        }
        echo '</div>';

        // Display pagination
        $big = 999999999; // Large number for pagination
        echo '<div class="pagination">';
        echo paginate_links(array(
            'base' => str_replace($big, '%#%', get_pagenum_link($big)),
            'format' => '?paged=%#%',
            'current' => max(1, $paged),
            'total' => $media_query->max_num_pages
        ));
        echo '</div>';
    } else {
        echo '<p>No media found.</p>';
    }

    wp_reset_postdata();
}

// Register the shortcode to display media
function media_control_media_shortcode($atts) {
    $atts = shortcode_atts(
        array(
            'media_type' => '',  // File types
            'media_count' => get_option('media_count', 5),  // Default number of files to display
        ), $atts, 'media_gallery'
    );

    // Store values in variables
    $media_type = $atts['media_type'];
    $media_count = $atts['media_count'];

    // Get the current page number from the URL
    $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;

    // Output the media
    ob_start();
    media_control_display_media($media_type, $media_count, $paged);
    return ob_get_clean();
}
add_shortcode('media_gallery', 'media_control_media_shortcode');
?>
