<?php
/*
Plugin Name: Content Analysis and Sitemap Generation
Description: A plugin for analyzing site content and manually generating separate sitemaps: one for pages, PDFs, images, posts, attachments, tags, and titles.
Version: 1.3
Author: Mbsmgroup
*/

// Register settings to store them
function my_plugin_register_settings() {
    register_setting('my_plugin_settings', 'my_plugin_settings');
    add_option('my_plugin_settings', array(
        'sitemap_frequency' => 'daily', // Default frequency
        'sitemap_priority' => '0.8', // Default priority
        'links_per_file' => 1000 // Default number of links per file
    ));
}
add_action('admin_init', 'my_plugin_register_settings');

// Add settings page
add_action('admin_menu', 'my_plugin_settings_page');
function my_plugin_settings_page() {
    add_options_page('Plugin Settings', 'Content Analysis', 'manage_options', 'my_plugin_settings', 'my_plugin_settings_callback');
}

function my_plugin_settings_callback() {
    ?>
    <div class="wrap">
        <h1>Content Analysis Plugin Settings</h1>

        <!-- Section 1: Sitemap Frequency Settings -->
        <h2>Sitemap Settings</h2>
        <form method="post" action="options.php">
            <?php
            // Output settings fields
            settings_fields('my_plugin_settings');
            do_settings_sections('my_plugin_settings');
            ?>

            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Sitemap Update Frequency</th>
                    <td>
                        <select name="my_plugin_settings[sitemap_frequency]">
                            <option value="hourly" <?php selected('hourly', get_option('my_plugin_settings')['sitemap_frequency']); ?>>Hourly</option>
                            <option value="daily" <?php selected('daily', get_option('my_plugin_settings')['sitemap_frequency']); ?>>Daily</option>
                            <option value="weekly" <?php selected('weekly', get_option('my_plugin_settings')['sitemap_frequency']); ?>>Weekly</option>
                            <option value="monthly" <?php selected('monthly', get_option('my_plugin_settings')['sitemap_frequency']); ?>>Monthly</option>
                            <option value="yearly" <?php selected('yearly', get_option('my_plugin_settings')['sitemap_frequency']); ?>>Yearly</option>
                            <option value="never" <?php selected('never', get_option('my_plugin_settings')['sitemap_frequency']); ?>>Never</option>
                        </select>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Page Priority in Sitemap</th>
                    <td>
                        <input type="number" step="0.1" min="0" max="1" name="my_plugin_settings[sitemap_priority]" value="<?php echo esc_attr(get_option('my_plugin_settings')['sitemap_priority']); ?>">
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Links per Sitemap File</th>
                    <td>
                        <input type="number" min="1" name="my_plugin_settings[links_per_file]" value="<?php echo esc_attr(get_option('my_plugin_settings')['links_per_file']); ?>">
                    </td>
                </tr>
            </table>

            <?php submit_button('Save Settings'); ?>
        </form>

        <h2>Generate Sitemap Files</h2>
        <form method="post" action="">
            <?php
            // Handle sitemap generation
            if (isset($_POST['generate_sitemap'])) {
                create_separate_sitemaps();
                echo '<div class="updated"><p>Sitemap files have been successfully generated. Check the links below:</p></div>';
            }
            ?>
            <input type="submit" name="generate_sitemap" class="button-primary" value="Generate Sitemap Files">
        </form>

        <?php
        // Display the links for generated files after the generation
        if (isset($_POST['generate_sitemap'])) {
            $folder_name = 'custom_sitemaps';
            $folder_path = ABSPATH . $folder_name . '/';

            $files = glob($folder_path . '*.xml');
            echo '<ul>';
            foreach ($files as $file) {
                $filename = basename($file);
                echo '<li><a href="' . esc_url(home_url('/') . $folder_name . '/' . $filename) . '" target="_blank">' . $filename . '</a></li>';
            }
            echo '</ul>';
        }
        ?>
    </div>
    <?php
}

// Create separate sitemaps and manage sitemap index
function create_separate_sitemaps() {
    // Retrieve plugin settings
    $settings = get_option('my_plugin_settings');
    $frequency = isset($settings['sitemap_frequency']) ? $settings['sitemap_frequency'] : 'daily';
    $priority = isset($settings['sitemap_priority']) ? $settings['sitemap_priority'] : '0.8';
    $links_per_file = isset($settings['links_per_file']) ? $settings['links_per_file'] : 1000;

    $folder_name = 'custom_sitemaps';
    $folder_path = ABSPATH . $folder_name . '/';

    // Create the folder if it doesn't exist
    if (!file_exists($folder_path)) {
        mkdir($folder_path, 0755, true);
    }

    // Define the different sitemap files
    $sitemaps = [
        'page.xml' => get_page_urls(),
        'pdf.xml' => get_pdf_urls(),
        'picture.xml' => get_picture_urls(),
        'post.xml' => get_post_urls(),
        'attachment.xml' => get_attachment_urls(),
        'tag.xml' => get_tag_urls(),
        'titles.xml' => get_titles_urls() // Add titles.xml
    ];

    // Create sitemap files for each content type
    foreach ($sitemaps as $filename => $urls) {
        if ($filename === 'titles.xml') {
            create_titles_sitemap($urls, $folder_path, $links_per_file);
        } else {
            create_sitemap($urls, $folder_path . $filename, $links_per_file);
        }
    }

    // Create sitemap index file
    $index_file = fopen($folder_path . 'mbsm.xml', 'w');
    fwrite($index_file, '<?xml version="1.0" encoding="UTF-8"?>' . PHP_EOL);
    fwrite($index_file, '<sitemapindex xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">' . PHP_EOL);

    foreach (glob($folder_path . '*.xml') as $sitemap_file) {
        fwrite($index_file, '<sitemap>' . PHP_EOL);
        fwrite($index_file, '<loc>' . esc_url(home_url('/') . $folder_name . '/' . basename($sitemap_file)) . '</loc>' . PHP_EOL);
        fwrite($index_file, '</sitemap>' . PHP_EOL);
    }

    fwrite($index_file, '</sitemapindex>' . PHP_EOL);
    fclose($index_file);
}

// Create a sitemap
function create_sitemap($urls, $file_path, $links_per_file) {
    // Split the URLs array into chunks
    $chunks = array_chunk($urls, $links_per_file);
    $index = 1;

    foreach ($chunks as $chunk) {
        $sitemap_file = fopen($file_path . '_' . $index . '.xml', 'w');
        fwrite($sitemap_file, '<?xml version="1.0" encoding="UTF-8"?>' . PHP_EOL);
        fwrite($sitemap_file, '<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">' . PHP_EOL);

        foreach ($chunk as $url) {
            fwrite($sitemap_file, '<url>' . PHP_EOL);
            fwrite($sitemap_file, '<loc>' . esc_url($url['loc']) . '</loc>' . PHP_EOL);
            fwrite($sitemap_file, '</url>' . PHP_EOL);
        }

        fwrite($sitemap_file, '</urlset>' . PHP_EOL);
        fclose($sitemap_file);
        $index++;
    }
}

// Create titles sitemap
function create_titles_sitemap($urls, $file_path, $links_per_file) {
    // Split the URLs array into chunks
    $chunks = array_chunk($urls, $links_per_file);
    $index = 1;

    foreach ($chunks as $chunk) {
        $sitemap_file = fopen($file_path . 'titles_' . $index . '.xml', 'w');
        fwrite($sitemap_file, '<?xml version="1.0" encoding="UTF-8"?>' . PHP_EOL);
        fwrite($sitemap_file, '<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">' . PHP_EOL);

        foreach ($chunk as $url) {
            fwrite($sitemap_file, '<url>' . PHP_EOL);
            fwrite($sitemap_file, '<title>' . esc_html($url['title']) . '</title>' . PHP_EOL);
            fwrite($sitemap_file, '<loc>' . esc_url($url['loc']) . '</loc>' . PHP_EOL);
            fwrite($sitemap_file, '</url>' . PHP_EOL);
        }

        fwrite($sitemap_file, '</urlset>' . PHP_EOL);
        fclose($sitemap_file);
        $index++;
    }
}

// Fetch URLs for pages
function get_page_urls() {
    $pages = get_pages();
    $urls = [];
    foreach ($pages as $page) {
        $urls[] = ['loc' => get_page_link($page)];
    }
    return $urls;
}

// Fetch URLs for posts
function get_post_urls() {
    $posts = get_posts(array('numberposts' => -1));
    $urls = [];
    foreach ($posts as $post) {
        $urls[] = ['loc' => get_permalink($post)];
    }
    return $urls;
}

// Fetch URLs for PDFs (example)
function get_pdf_urls() {
    // Implement your logic for fetching PDF URLs
    return [];
}

// Fetch URLs for images (example)
function get_picture_urls() {
    // Implement your logic for fetching image URLs
    return [];
}

// Fetch URLs for attachments
function get_attachment_urls() {
    $attachments = get_posts(array(
        'post_type' => 'attachment',
        'numberposts' => -1
    ));
    $urls = [];
    foreach ($attachments as $attachment) {
        $urls[] = ['loc' => wp_get_attachment_url($attachment->ID)];
    }
    return $urls;
}

// Fetch URLs for tags
function get_tag_urls() {
    $tags = get_tags();
    $urls = [];
    foreach ($tags as $tag) {
        $urls[] = ['loc' => get_tag_link($tag)];
    }
    return $urls;
}

// Fetch URLs for titles.xml (modified for titles and links)
function get_titles_urls() {
    $posts = get_posts(array('numberposts' => -1));
    $urls = [];
    foreach ($posts as $post) {
        $urls[] = ['title' => get_the_title($post), 'loc' => get_permalink($post)];
    }
    return $urls;
}
?>
